@@ -9,17 +9,17 @@ import numpy as np
 import numpy.typing as npt
 
 
-def _local_da(neighbors, data, point_index) -> npt.NDArray[np.float]:
+def _local_da(neighbors, data, point_index) -> np.float64:
     """
     Average absolute difference between the
     value at point_index and its neighbors.
     """
-    return np.mean(np.abs(data[point_index] - data[tuple(neighbors)]))
+    return np.mean(np.abs(data[point_index] - data[list(neighbors)]))  # type: ignore
 
 
 def difference_average(neighbor_graph: tuple[set[int], ...],
-                       data: npt.NDArray[np.float]
-                       ) -> Iterator[npt.NDArray[np.float]]:
+                       data: npt.NDArray[np.floating]
+                       ) -> Iterator[np.float64]:
     """
     Average absolute difference between the
     value at point_index and its neighbors
